@@ -15,6 +15,10 @@ class Encoder(json.JSONEncoder):
             return self.default(pd.Timestamp(value.astype(int)))
         if isinstance(value, np.ndarray):
             return value.tolist()
+        if isinstance(value, (np.int64, np.int32, np.int16, np.int8, np.int_)):
+            return int(value)
+        if isinstance(value, (np.double, np.float64, np.float_)):
+            return float(value)
         if isinstance(value, (pd.DataFrame, pd.Series, pd.Index)): 
             return value.values.tolist()
         return super().default(value)
